@@ -42,6 +42,7 @@ typedef struct {
 
 	gboolean has_arrow;
 	gboolean composited;
+	gboolean action_icons;
 
 	int width;
 	int height;
@@ -404,12 +405,8 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	windata->summary_label = gtk_label_new(NULL);
 	gtk_widget_show(windata->summary_label);
 	gtk_box_pack_start(GTK_BOX(vbox), windata->summary_label, TRUE, TRUE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (windata->summary_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->summary_label), 0.0);
-#else
-	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0.0, 0.0);
-#endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->summary_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->summary_label), PANGO_WRAP_WORD_CHAR);
 
@@ -427,12 +424,8 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	windata->body_label = gtk_label_new(NULL);
 	gtk_widget_show(windata->body_label);
 	gtk_box_pack_start(GTK_BOX(vbox), windata->body_label, TRUE, TRUE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (windata->body_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->body_label), 0.0);
-#else
-	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0.0, 0.0);
-#endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->body_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->body_label), PANGO_WRAP_WORD_CHAR);
     gtk_label_set_max_width_chars (GTK_LABEL (windata->body_label), 50);
@@ -450,27 +443,32 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	return GTK_WINDOW(win);
 }
 
-void set_notification_hints(GtkWindow* nw, GHashTable* hints)
+void set_notification_hints(GtkWindow *nw, GHashTable *hints)
 {
-	WindowData* windata = g_object_get_data(G_OBJECT(nw), "windata");
+	WindowData *windata = g_object_get_data(G_OBJECT(nw), "windata");
+	GValue *value = NULL, *icon_value = NULL;
 
 	g_assert(windata != NULL);
 
-	GValue* value = (GValue*) g_hash_table_lookup(hints, "urgency");
+	value = (GValue *)g_hash_table_lookup(hints, "urgency");
+	icon_value = (GValue *)g_hash_table_lookup(hints, "action-icons");
 
 	if (value != NULL && G_VALUE_HOLDS_UCHAR(value))
 	{
 		windata->urgency = g_value_get_uchar(value);
 
-		if (windata->urgency == URGENCY_CRITICAL)
-		{
+		if (windata->urgency == URGENCY_CRITICAL) {
 			gtk_window_set_title(GTK_WINDOW(nw), "Critical Notification");
-		}
-		else
-		{
+		} else {
 			gtk_window_set_title(GTK_WINDOW(nw), "Notification");
 		}
 	}
+
+	/* Determine if action-icons have been requested */
+	if (icon_value != NULL && G_VALUE_HOLDS_BOOLEAN(icon_value))
+	{
+		windata->action_icons = g_value_get_boolean(icon_value);
+	}
 }
 
 void set_notification_timeout(GtkWindow *nw, glong timeout)
@@ -513,15 +511,12 @@ void set_notification_text(GtkWindow* nw, const char* summary, const char* body)
 	gtk_label_set_markup(GTK_LABEL(windata->summary_label), str);
 	g_free(str);
 
-	if (strstr(body, "&amp;") || strstr(body, "&lt;") || strstr(body, "&gt;") || strstr(body, "&apos;") || strstr(body, "&quot;"))
+	if (pango_parse_markup (body, -1, 0, NULL, NULL, NULL, NULL))
 	{
-		gtk_label_set_markup(GTK_LABEL(windata->body_label), body);
+		gtk_label_set_markup (GTK_LABEL (windata->body_label), body);
 	}
-	else
-	{
-		quoted = g_markup_escape_text(body, -1);
-		gtk_label_set_markup(GTK_LABEL(windata->body_label), quoted);
-		g_free(quoted);
+	else {
+		gtk_label_set_text (GTK_LABEL (windata->body_label), body);
 	}
 
 	if (body == NULL || *body == '\0')
@@ -715,21 +710,28 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 		gtk_widget_show(windata->actions_box);
 		update_content_hbox_visibility(windata);
 
-		windata->pie_countdown = gtk_drawing_area_new();
+		/* Don't try to re-add a pie_countdown */
+		if (!windata->pie_countdown) {
+			windata->pie_countdown = gtk_drawing_area_new();
+			gtk_widget_set_halign (windata->pie_countdown, GTK_ALIGN_END);
+			gtk_widget_set_valign (windata->pie_countdown, GTK_ALIGN_CENTER);
+			gtk_widget_show(windata->pie_countdown);
 
-		gtk_widget_set_halign (windata->pie_countdown, GTK_ALIGN_END);
-		gtk_widget_show(windata->pie_countdown);
+			gtk_box_pack_end (GTK_BOX (windata->actions_box), windata->pie_countdown, FALSE, TRUE, 0);
+			gtk_widget_set_size_request(windata->pie_countdown,
+						    PIE_WIDTH, PIE_HEIGHT);
+			g_signal_connect(G_OBJECT(windata->pie_countdown), "draw",
+					 G_CALLBACK(on_countdown_draw), windata);
+		}
+	}
 
-		gtk_box_pack_end (GTK_BOX (windata->actions_box), windata->pie_countdown, FALSE, TRUE, 0);
-		gtk_widget_set_size_request(windata->pie_countdown, PIE_WIDTH, PIE_HEIGHT);
-		g_signal_connect(G_OBJECT(windata->pie_countdown), "draw", G_CALLBACK(on_countdown_draw), windata);
+	if (windata->action_icons) {
+		button = gtk_button_new_from_icon_name(key, GTK_ICON_SIZE_BUTTON);
+		goto add_button;
 	}
 
 	button = gtk_button_new();
 	gtk_widget_show(button);
-	gtk_box_pack_start(GTK_BOX(windata->actions_box), button, FALSE, FALSE, 0);
-	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
-	gtk_container_set_border_width(GTK_CONTAINER(button), 0);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show(hbox);
@@ -753,19 +755,22 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 	label = gtk_label_new(NULL);
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-#endif
 	buf = g_strdup_printf("<small>%s</small>", text);
 	gtk_label_set_markup(GTK_LABEL(label), buf);
 	g_free(buf);
 
+add_button:
+	gtk_box_pack_start(GTK_BOX(windata->actions_box), button, FALSE, FALSE, 0);
+	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+	gtk_container_set_border_width(GTK_CONTAINER(button), 0);
+
 	g_object_set_data(G_OBJECT(button), "_nw", nw);
 	g_object_set_data_full(G_OBJECT(button), "_action_key", g_strdup(key), g_free);
 	g_signal_connect(G_OBJECT(button), "button-release-event", G_CALLBACK(on_action_clicked), cb);
+
+	gtk_widget_show_all(windata->actions_box);
 }
 
 void clear_notification_actions(GtkWindow* nw)
